aboutsummaryrefslogtreecommitdiffstats
path: root/csit/plans/sdnc/setup.sh
diff options
context:
space:
mode:
Diffstat (limited to 'csit/plans/sdnc/setup.sh')
-rw-r--r--csit/plans/sdnc/setup.sh9
1 files changed, 8 insertions, 1 deletions
diff --git a/csit/plans/sdnc/setup.sh b/csit/plans/sdnc/setup.sh
index 2a418e6f..91783582 100644
--- a/csit/plans/sdnc/setup.sh
+++ b/csit/plans/sdnc/setup.sh
@@ -18,11 +18,18 @@
# Modifications copyright (c) 2021 AT&T Intellectual Property
#
# Remove all dangling images
docker image prune -f
+echo "Remove onap repository artifacts"
+rm -r /tmp/r/org/onap
+echo "Remove all target folders from workspace"
+rm -r $(find /w/workspace -name target)
###################### Netconf Simulator Setup ######################
+echo "Clean"
+sudo apt clean
+
# Get integration/simulators
if [ -d ${WORKSPACE}/archives/pnf-simulator ]
then
@@ -18,11 +18,18 @@
# Modifications copyright (c) 2021 AT&T Intellectual Property
#
-# Remove all dangling images
+# Remove all dangling images and cleanup /w/workspace and /tmp
docker image prune -f